@@ -16,7 +16,7 @@
  
     You should have received a copy of the GNU General Public License
     along with gvpe; if not, write to the Free Software
-    Foundation, Inc. 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc. 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef GVPE_SOCKINFO_H__
@@ -66,7 +66,12 @@ struct sockinfo
   };
 
 bool operator == (const sockinfo &a, const sockinfo &b);
-bool operator < (const sockinfo &a, const sockinfo &b);
+bool operator <  (const sockinfo &a, const sockinfo &b);
+
+inline bool operator != (const sockinfo &a, const sockinfo &b)
+{
+  return !(a == b);
+}
 
 #endif
 
